@@ -1,14 +1,10 @@
 from django.db import models
 # Create your models here.
 
+from celex.models import Orthography
+
 import caching.base
 
-class Orthography(models.Model):
-    spelling = models.CharField(max_length = 250,unique=True)
-
-    def __unicode__(self):
-        return self.word
-
 class Trigram(caching.base.CachingMixin, models.Model):
     word = models.ForeignKey(Orthography,related_name='word')
     word_i_minus_one = models.ForeignKey(Orthography,related_name='word_i_minus_one')
