@@ -11,7 +11,7 @@ from django.http import HttpResponse
 
 from .models import *
 from .forms import *
-from .tasks import reset_trigrams,gen_bigrams
+from .tasks import reset_trigrams
 
 @login_required
 def index(request):
@@ -31,17 +31,4 @@ def reset(request):
         form = ResetForm()
         return render(request,'ngrams/form.html',{'form':form})
 
-@login_required
-def get_bigrams(request):
-    if request.user.is_superuser:
-        if request.method == 'POST':
-            form = ResetForm(request.POST)
-            if form.is_valid():
-                gen_bigrams.delay()
-                return redirect(index)
-            else:
-                form = ResetForm()
-                render(request,'ngrams/form.html',{'form':form})
-        form = ResetForm()
-        return render(request,'ngrams/form.html',{'form':form})
 
